---
hide:
  - toc
  - navigation
  - footer
---

# Mismo

Mismo is a python framework for
[Record Linkage](https://en.wikipedia.org/wiki/Record_linkage), built on top
of [Ibis](https://ibis-project.org/). It allows you to deduplicate and link
records from tables that don't have a unique identifier.

- Take a database of campaign contributions and determine which
  were made by the same person
- Determining which product listings actually refer to the same item.
- Linking businesses across different datasets.

## Example

See the [example notebooks](examples/patent_deduplication).